@@ -1,8 +1,13 @@
 # -*- coding: utf-8 -*-
-from lektor.pluginsystem import Plugin
+from lektor.pluginsystem import Plugin  # type: ignore
 
 
-def nf_resize(source: str, nf_resize='fit', h='', w='') -> str:
+def nf_resize(
+    source: str,
+    nf_resize: str = 'fit',
+    h: str = '',
+    w: str = ''
+) -> str:
     if nf_resize == 'fit' or nf_resize == 'smartcrop':
         if h or w:
             source += f'?nf_resize={nf_resize}'
@@ -12,6 +17,8 @@ def nf_resize(source: str, nf_resize='fit', h='', w='') -> str:
 
         if w:
             source += f'&w={str(w)}'
+    elif nf_resize not in ['fit', 'smartcrop']:
+        raise Exception
     return source
 
 
